# mediaApiClient
It is an opensource library for working with api ContentApiGate, written in python.

## Installation

Install the current version mediaApiClient with [PyPI](https://pypi.org/project/mediaApiClient/):

```bash
pip install mediaApiClient
```

## Documents

* Controllers
  * [Working with Content Controller](https://github.com/semen-shilovski/mediaApiClient/blob/main/docs/controllers/content.md)
  * [Working with Stream Controller](https://github.com/semen-shilovski/mediaApiClient/blob/main/docs/controllers/stream.md)
  * [Working with Service Controller](https://github.com/semen-shilovski/mediaApiClient/blob/main/docs/controllers/service.md)
  * [Working with Account Controller](https://github.com/semen-shilovski/mediaApiClient/blob/main/docs/controllers/account.md)
  * [Working with Compilation Controller](https://github.com/semen-shilovski/mediaApiClient/blob/main/docs/controllers/compilation.md)

## License

The module is available as open source under the terms of the [Apache License, Version 2.0](https://opensource.org/licenses/Apache-2.0)